@@ -8,16 +8,18 @@ use lib               catdir( $Bin, updir, 'lib' ), catdir( $Bin, 'lib' );
 
 use Test::More;
 use Test::Requires { version => 0.88 };
-use Test::Requires { 'Exporter::Tiny' => 0.042 };
 use Module::Build;
+use Sys::Hostname;
 
-my $notes = {}; my $perl_ver;
+my $builder; my $notes = {}; my $perl_ver;
 
 BEGIN {
-   my $builder = eval { Module::Build->current };
-      $builder and $notes = $builder->notes;
-      $perl_ver = $notes->{min_perl_version} || 5.008;
-      $Bin =~ m{ : .+ : }mx and plan skip_all => 'Two colons in $Bin path';
+   $builder   = eval { Module::Build->current };
+   $builder and $notes = $builder->notes;
+   $perl_ver  = $notes->{min_perl_version} || 5.008;
+   $Bin =~ m{ : .+ : }mx and plan skip_all => 'Two colons in $Bin path';
+   $notes->{testing} and lc hostname eq 'digitalis'
+      and plan skip_all => 'Broken smoker a54c1c84-6bf5-1014-b4f9-dcd54300afcd';
 }
 
 use Test::Requires "${perl_ver}";
